@@ -74,6 +74,8 @@ public:
     {
     }
 
+    void doLogin();
+
     SmtpJob *q;
     KSmtp::Session *session = nullptr;
     KSmtp::SessionUiProxy::Ptr uiProxy;
@@ -234,7 +236,6 @@ void SmtpJob::startLoginJob()
         return;
     }
 
-    auto login = new KSmtp::LoginJob(d->session);
     auto user = transport()->userName();
     auto passwd = transport()->password();
     if ((user.isEmpty() || passwd.isEmpty())
@@ -244,6 +245,7 @@ void SmtpJob::startLoginJob()
             nullptr,
             KPasswordDialog::ShowUsernameLine
             |KPasswordDialog::ShowKeepPassword);
+        dlg->setAttribute(Qt::WA_DeleteOnClose, true);
         dlg->setPrompt(i18n("You need to supply a username and a password "
                             "to use this SMTP server."));
         dlg->setKeepPassword(transport()->storePassword());
@@ -251,31 +253,41 @@ void SmtpJob::startLoginJob()
         dlg->setUsername(user);
         dlg->setPassword(passwd);
 
-        bool gotIt = false;
-        if (dlg->exec()) {
+        connect(this, &KJob::result, dlg, &QDialog::reject);
+
+        connect(dlg, &QDialog::finished, this, [this, dlg](const int result) {
+            if (result == QDialog::Rejected) {
+                setError(KilledJobError);
+                emitResult();
+                return;
+            }
+
             transport()->setUserName(dlg->username());
             transport()->setPassword(dlg->password());
             transport()->setStorePassword(dlg->keepPassword());
             transport()->save();
-            gotIt = true;
-        }
-        delete dlg;
 
-        if (!gotIt) {
-            setError(KilledJobError);
-            emitResult();
-            return;
-        }
+            d->doLogin();
+        });
+        dlg->open();
+
+        return;
     }
 
-    if (transport()->authenticationType() == Transport::EnumAuthenticationType::XOAUTH2) {
+    d->doLogin();
+}
+
+void SmtpJobPrivate::doLogin()
+{
+    QString passwd = q->transport()->password();
+    if (q->transport()->authenticationType() == Transport::EnumAuthenticationType::XOAUTH2) {
         passwd = passwd.left(passwd.indexOf(QLatin1Char('\001')));
-    } else {
-        passwd = transport()->password();
     }
-    login->setUserName(transport()->userName());
+
+    auto login = new KSmtp::LoginJob(session);
+    login->setUserName(q->transport()->userName());
     login->setPassword(passwd);
-    switch (transport()->authenticationType()) {
+    switch (q->transport()->authenticationType()) {
     case TransportBase::EnumAuthenticationType::PLAIN:
         login->setPreferedAuthMode(KSmtp::LoginJob::Plain);
         break;
@@ -298,11 +310,11 @@ void SmtpJob::startLoginJob()
         login->setPreferedAuthMode(KSmtp::LoginJob::GSSAPI);
         break;
     default:
-        qCWarning(MAILTRANSPORT_SMTP_LOG) << "Unknown authentication mode" << transport()->authenticationTypeString();
+        qCWarning(MAILTRANSPORT_SMTP_LOG) << "Unknown authentication mode" << q->transport()->authenticationTypeString();
         break;
     }
 
-    switch (transport()->encryption()) {
+    switch (q->transport()->encryption()) {
     case Transport::EnumEncryption::None:
         login->setEncryptionMode(KSmtp::LoginJob::Unencrypted);
         break;
@@ -313,12 +325,12 @@ void SmtpJob::startLoginJob()
         login->setEncryptionMode(KSmtp::LoginJob::SSLorTLS);
         break;
     default:
-        qCWarning(MAILTRANSPORT_SMTP_LOG) << "Unknown encryption mode" << transport()->encryption();
+        qCWarning(MAILTRANSPORT_SMTP_LOG) << "Unknown encryption mode" << q->transport()->encryption();
         break;
     }
 
-    connect(login, &KJob::result, this, &SmtpJob::slotResult);
-    addSubjob(login);
+    q->connect(login, &KJob::result, q, &SmtpJob::slotResult);
+    q->addSubjob(login);
     login->start();
     qCDebug(MAILTRANSPORT_SMTP_LOG) << "Login started";
 }
