@@ -1,22 +1,9 @@
 /*
   Copyright (c) 2006 - 2007 Volker Krause <vkrause@kde.org>
-  Copyright (C) 2007 KovoKs <info@kovoks.nl>
-  Copyright (c) 2008 Thomas McGuire <thomas.mcguire@gmx.net>
+  SPDX-FileCopyrightText: 2007 KovoKs <info@kovoks.nl>
+  SPDX-FileCopyrightText: 2008 Thomas McGuire <thomas.mcguire@gmx.net>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 // Own
@@ -133,7 +120,7 @@ void ServerTestPrivate::finalResult()
         resultsAsVector.append(res);
     }
 
-    emit q->finished(resultsAsVector);
+    Q_EMIT q->finished(resultsAsVector);
 }
 
 QVector<int> ServerTestPrivate::parseAuthenticationList(const QStringList &authentications)
