@@ -1,20 +1,7 @@
 /*
     Copyright (c) 2006 - 2007 Volker Krause <vkrause@kde.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "transport.h"
@@ -251,7 +238,7 @@ bool Transport::usrSave()
     }
     TransportManager::self()->emitChangesCommitted();
     if (name() != d->oldName) {
-        emit TransportManager::self()->transportRenamed(id(), d->oldName, name());
+        Q_EMIT TransportManager::self()->transportRenamed(id(), d->oldName, name());
         d->oldName = name();
     }
 
@@ -337,9 +324,3 @@ TransportType Transport::transportType() const
     }
     return d->transportType;
 }
-
-QByteArray Transport::toJson() const
-{
-    //TODO create json info
-    return {};
-}
