@@ -1,20 +1,7 @@
 /*
   Copyright (c) 2006 - 2007 Volker Krause <vkrause@kde.org>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "transportmanager.h"
@@ -34,6 +21,7 @@
 #include <QDBusConnectionInterface>
 #include <QDBusServiceWatcher>
 #include <QPointer>
+#include <QRandomGenerator>
 #include <QRegularExpression>
 #include <QStringList>
 
@@ -43,7 +31,6 @@
 #include <KEMailSettings>
 #include <KLocalizedString>
 #include <KMessageBox>
-#include <KRandom>
 #include <Kdelibs4ConfigMigrator>
 
 #include <KWallet>
@@ -60,9 +47,7 @@ class TransportManagerPrivate
 {
 public:
     TransportManagerPrivate(TransportManager *parent)
-        : config(nullptr)
-        , wallet(nullptr)
-        , q(parent)
+        : q(parent)
     {
     }
 
@@ -401,7 +386,7 @@ void TransportManager::removeTransport(int id)
     if (plugin) {
         plugin->cleanUp(t);
     }
-    emit transportRemoved(t->id(), t->name());
+    Q_EMIT transportRemoved(t->id(), t->name());
 
     d->transports.removeAll(t);
     d->validateDefault();
@@ -519,8 +504,8 @@ void TransportManager::emitChangesCommitted()
 {
     d->myOwnChange = true; // prevent us from reading our changes again
     d->appliedChange = false; // but we have to read them at least once
-    emit transportsChanged();
-    emit changesCommitted();
+    Q_EMIT transportsChanged();
+    Q_EMIT changesCommitted();
 }
 
 void TransportManagerPrivate::slotTransportsChanged()
@@ -536,7 +521,7 @@ void TransportManagerPrivate::slotTransportsChanged()
     // FIXME: this deletes existing transport objects!
     readConfig();
     appliedChange = true; // to prevent recursion
-    emit q->transportsChanged();
+    Q_EMIT q->transportsChanged();
 }
 
 int TransportManagerPrivate::createId() const
@@ -549,7 +534,7 @@ int TransportManagerPrivate::createId() const
     usedIds << 0; // 0 is default for unknown
     int newId;
     do {
-        newId = KRandom::random();
+        newId = QRandomGenerator::global()->generate();
     } while (usedIds.contains(newId));
     return newId;
 }
@@ -607,7 +592,7 @@ void TransportManager::loadPasswords()
         job->start();
     }
 
-    emit passwordsChanged();
+    Q_EMIT passwordsChanged();
 }
 
 void TransportManager::loadPasswordsAsync()
@@ -671,7 +656,7 @@ void TransportManagerPrivate::validateDefault()
         if (q->isEmpty()) {
             defaultTransportId = -1;
         } else {
-            defaultTransportId = transports.first()->id();
+            defaultTransportId = transports.constFirst()->id();
             writeConfig();
         }
     }
