@@ -1,20 +1,7 @@
 /*
-  Copyright (c) 2009 Constantin Berzan <exit3219@gmail.com>
+  SPDX-FileCopyrightText: 2009 Constantin Berzan <exit3219@gmail.com>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef MAILTRANSPORT_MESSAGEQUEUEJOB_H
@@ -104,33 +91,33 @@ public:
     Q_REQUIRED_RESULT KMime::Message::Ptr message() const;
 
     /**
-      Returns a reference to the dispatch mode attribue for this message.
+      Returns a reference to the dispatch mode attribute for this message.
       Modify the returned attribute to change the dispatch mode.
     */
     DispatchModeAttribute &dispatchModeAttribute();
 
     /**
-      Returns a reference to the address attribue for this message.
+      Returns a reference to the address attribute for this message.
       Modify the returned attribute to change the receivers or the from
       address.
     */
     Akonadi::AddressAttribute &addressAttribute();
 
     /**
-      Returns a reference to the transport attribue for this message.
+      Returns a reference to the transport attribute for this message.
       Modify the returned attribute to change the transport used for
       sending the mail.
     */
     TransportAttribute &transportAttribute();
 
     /**
-      Returns a reference to the sent behaviour attribue for this message.
+      Returns a reference to the sent behaviour attribute for this message.
       Modify the returned attribute to change the sent behaviour.
     */
     SentBehaviourAttribute &sentBehaviourAttribute();
 
     /**
-      Returns a reference to the sent action attribue for this message.
+      Returns a reference to the sent action attribute for this message.
       Modify the returned attribute to change the sent actions.
     */
     SentActionAttribute &sentActionAttribute();
